]> sigrok.org Git - libsigrokdecode.git/commitdiff
srd: SRD_ERR_ARGS -> SRD_ERR_ARG.
authorUwe Hermann <redacted>
Wed, 21 Dec 2011 18:09:46 +0000 (19:09 +0100)
committerUwe Hermann <redacted>
Thu, 22 Dec 2011 13:16:07 +0000 (14:16 +0100)
This is done to be consistent with libsigrok's SR_ERR_ARG (nicer that way).

controller.c
log.c
sigrokdecode.h

index 31aad0e0bf060770ca69eb7d18fd370f7ce2f0f6..882cafbe272f25e0bee3fce5d2eb6693407b3a8c 100644 (file)
@@ -311,11 +311,11 @@ int srd_run_decoder(struct srd_decoder_instance *dec,
 
        /* Return an error upon unusable input. */
        if (dec == NULL)
-               return SRD_ERR_ARGS; /* TODO: More specific error? */
+               return SRD_ERR_ARG; /* TODO: More specific error? */
        if (inbuf == NULL)
-               return SRD_ERR_ARGS; /* TODO: More specific error? */
+               return SRD_ERR_ARG; /* TODO: More specific error? */
        if (inbuflen == 0) /* No point in working on empty buffers. */
-               return SRD_ERR_ARGS; /* TODO: More specific error? */
+               return SRD_ERR_ARG; /* TODO: More specific error? */
 
        /* TODO: Error handling. */
        py_instance = dec->py_instance;
diff --git a/log.c b/log.c
index a051a15789ed74eca65dea12ebaba45faa042b35..6add4470c39ede8d963a8ca69ccc2b603d40b1f4 100644 (file)
--- a/log.c
+++ b/log.c
@@ -34,13 +34,13 @@ static int srd_loglevel = SRD_LOG_WARN; /* Show errors+warnings per default. */
  *
  * @param loglevel The loglevel to set (SRD_LOG_NONE, SRD_LOG_ERR,
  *                 SRD_LOG_WARN, SRD_LOG_INFO, SRD_LOG_DBG, or SRD_LOG_SPEW).
* @return SRD_OK upon success, SRD_ERR_ARGS upon invalid loglevel.
  */
 int srd_set_loglevel(int loglevel)
 {
        if (loglevel < SRD_LOG_NONE || loglevel > SRD_LOG_SPEW) {
                srd_err("log: %s: invalid loglevel %d", __func__, loglevel);
-               return SRD_ERR_ARGS;
+               return SRD_ERR_ARG;
        }
 
        srd_loglevel = loglevel;
index f7d93accd39c564a1edb52186ec1156f2032d2f8..4d7567f9ff0b2ca625cd54056da421b713da3993 100644 (file)
@@ -49,7 +49,7 @@ extern "C" {
 #define SRD_OK                  0 /**< No error */
 #define SRD_ERR                        -1 /**< Generic/unspecified error */
 #define SRD_ERR_MALLOC         -2 /**< Malloc/calloc/realloc error */
-#define SRD_ERR_ARGS           -3 /**< Function argument error */
+#define SRD_ERR_ARG            -3 /**< Function argument error */
 #define SRD_ERR_PYTHON         -4 /**< Python C API error */
 #define SRD_ERR_DECODERS_DIR   -5 /**< Protocol decoder path invalid */
@@ -34,13 +34,13 @@ static int srd_loglevel = SRD_LOG_WARN; /* Show errors+warnings per default. */
  * @param loglevel The loglevel to set (SRD_LOG_NONE, SRD_LOG_ERR,
  *                 SRD_LOG_WARN, SRD_LOG_INFO, SRD_LOG_DBG, or SRD_LOG_SPEW).
- * @return SRD_OK upon success, SRD_ERR_ARGS upon invalid loglevel.
+ * @return SRD_OK upon success, SRD_ERR_ARG upon invalid loglevel.
  */
 int srd_set_loglevel(int loglevel)